{
  pkgs,
  inputs,
  ...
}: {
  imports = [
    ./apps/firefox.nix
    ./apps/syncthing.nix
  ];

  home.packages = [
    pkgs.pavucontrol # volume control stuff

    # Social
    pkgs.signal-desktop
    pkgs.webcord # pkgs.webcord-vencord
    pkgs.telegram-desktop

    # Productivity/Documents
    pkgs.keepassxc
    pkgs.libreoffice
    pkgs.gimp
    pkgs.krita
    pkgs.okular
    pkgs.localsend

    pkgs.ffmpeg # Generally useful

    # Music
    #pkgs.feishin # sonixd replacement; emily said that they need to fix something with it, so keeping the comment here
    pkgs.sonixd # Music player; desktop app for Navidrome. Replace w/ Feishin when that supports Subsonic API.
    pkgs.spotify # Proprietary

    # Documents

    # emily suggested I try these (albiet via their web thing), so keeping them commented
    #pkgs.typst # TeX alternative
    #pkgs.tinymist # LSP for Typst

    # Dev
    pkgs.ptyxis # Terminal emulator
    pkgs.vscodium
    #pkgs.jetbrains.rider
    #pkgs.jetbrains.rust-rover
    #pkgs.helix
    #pkgs.zed-editor

    pkgs.obsidian
  ];

  programs.mpv.enable = true; # media player

  programs.zathura.enable = true; # pdf viewer

  programs.thunderbird = {
    enable = true;
    profiles.default = {
      isDefault = true;
    };
  };

  programs.vscode = {
    enable = true;
    package = pkgs.vscodium;
    enableUpdateCheck = false;
    userSettings = {
      "window.menuBarVisibility" = "toggle";

      # instead of dling a copy of rust analyzer, use the one from where we launched vscode
      "rust-analyzer.server.path" = "rust-analyzer"; 

      # Library sources for rust-analyzer shall be read-only
      "files.readonlyInclude" = {
        "**/.cargo/registry/src/**/*.rs" = true;
        "**/lib/rustlib/src/rust/library/**/*.rs" = true;
      };
    };
    extensions = with pkgs.vscode-extensions; [
      vscodevim.vim
      mkhl.direnv
      jnoortheen.nix-ide
    ];
  };
}
